<?php
/**
 * @package    MiloTheme/Milo Bibo
 * @version    1.0.0
 * @author     Administrator <admin@milotheme.com>
 * @copyright  Copyright (c) 2016, MiloTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       http://milotheme.com
*/

if ( !defined('ABSPATH') ) die('-1');

include_once( plugin_dir_path(__FILE__) . 'metaboxes/spec.php' ); // Add new metabox

if ( ! class_exists( 'Milo_Portfolio_Post_Type' ) ) {
    class Milo_Portfolio_Post_Type {

        protected $prefix;

        public function __construct() {
            $this->prefix = 'milo_portfolio';

            add_action('init', array($this,'milo_portfolio'), '5'); // Must hook register post type and taxonomies with hight piority go make get_term() working
            add_action('admin_init', array($this, 'milo_register_meta_boxes'));

            if ( is_admin() ) {
                add_action( 'do_meta_boxes', array( $this, 'remove_plugin_metaboxes' ) );
                // Add custom columns reference: http://code.tumilolus.com/articles/add-a-custom-column-in-posts-and-custom-post-types-admin-screen--wp-24934
                add_filter( 'manage_milo_portfolio_posts_columns', array( $this, 'add_columns' ) );
                add_action( 'manage_milo_portfolio_posts_custom_column', array( $this, 'set_columns_value'), 10, 2);
            }
        }

        function remove_plugin_metaboxes() {
            remove_meta_box( 'mymetabox_revslider_0', 'milo_portfolio', 'normal' );
            remove_meta_box( 'handlediv', 'milo_portfolio', 'normal' );
            remove_meta_box( 'commentsdiv', 'milo_portfolio', 'normal' );
        }

        function milo_portfolio() {
            $prefix = $this->prefix;

            $labels = array(
                'menu_name'          => esc_html__( 'Portfolio', 'milo-bibo' ),
                'singular_name'      => esc_html__( 'Single Portfolio', 'milo-bibo' ),
                'name'               => esc_html__( 'Portfolio', 'milo-bibo' ),
                'add_new'            => esc_html__( 'Add New', 'milo-bibo' ) ,
                'add_new_item'       => esc_html__( 'Add New Portfolio', 'milo-bibo' ) ,
                'edit_item'          => esc_html__( 'Edit Portfolio', 'milo-bibo' ) ,
                'new_item'           => esc_html__( 'Add New Portfolio', 'milo-bibo' ) ,
                'view_item'          => esc_html__( 'View Portfolio', 'milo-bibo' ) ,
                'search_items'       => esc_html__( 'Search Portfolio', 'milo-bibo' ) ,
                'not_found'          => esc_html__( 'No Portfolio items found', 'milo-bibo' ) ,
                'not_found_in_trash' => esc_html__( 'No Portfolio items found in trash', 'milo-bibo' ) ,
                'parent_item_colon'  => ''
            );

            $args = array(
                'labels'                => $labels,
                'description'           => esc_html__( 'Display portfolio', 'milo-bibo' ),
                'hierarchical'          => false,
                'public'                => true,
                'show_ui'               => true,
                'show_in_menu'          => true,
                'menu_icon'             => 'dashicons-screenoptions',
                'menu_position'         => 5,
                'show_in_admin_bar'     => true,
                'show_in_nav_menus'     => true,
                'can_export'            => true,
                'has_archive'           => true,
                'exclude_from_search'   => false,
                'publicly_queryable'    => true,
                'capability_type'       => 'post',
                'supports'              => array( 'title', 'editor', 'thumbnail', 'excerpt' ),
                'rewrite'           => array(
                    'slug'          => 'portfolio',
                    'with_front'    => false
                ) ,
            );
            register_post_type( 'milo_portfolio', $args );

            // Register a taxonomy for Project Categories.
            $category_labels = array(
                'name'                          => esc_html__( 'Portfolio Categories', 'milo-bibo' ) ,
                'singular_name'                 => esc_html__( 'Portfolio Category', 'milo-bibo' ) ,
                'menu_name'                     => esc_html__( 'Categories', 'milo-bibo' ) ,
                'all_items'                     => esc_html__( 'All Portfolio Categories', 'milo-bibo' ) ,
                'edit_item'                     => esc_html__( 'Edit Portfolio Category', 'milo-bibo' ) ,
                'view_item'                     => esc_html__( 'View Portfolio Category', 'milo-bibo' ) ,
                'update_item'                   => esc_html__( 'Update Portfolio Category', 'milo-bibo' ) ,
                'add_new_item'                  => esc_html__( 'Add New Portfolio Category', 'milo-bibo' ) ,
                'new_item_name'                 => esc_html__( 'New Portfolio Category Name', 'milo-bibo' ) ,
                'parent_item'                   => esc_html__( 'Parent Portfolio Category', 'milo-bibo' ) ,
                'parent_item_colon'             => esc_html__( 'Parent Portfolio Category:', 'milo-bibo' ) ,
                'search_items'                  => esc_html__( 'Search Portfolio Categories', 'milo-bibo' ) ,
                'popular_items'                 => esc_html__( 'Popular Portfolio Categories', 'milo-bibo' ) ,
                'separate_items_with_commas'    => esc_html__( 'Separate Portfolio Categories with commas', 'milo-bibo' ) ,
                'add_or_remove_items'           => esc_html__( 'Add or remove Portfolio Categories', 'milo-bibo' ) ,
                'choose_from_most_used'         => esc_html__( 'Choose from the most used Portfolio Categories', 'milo-bibo' ) ,
                'not_found'                     => esc_html__( 'No Portfolio Categories found', 'milo-bibo' ) ,
            );

            $category_args = array(
                'labels'            => $category_labels,
                'public'            => false,
                'show_ui'           => true,
                'show_in_nav_menus' => false,
                'show_tagcloud'     => false,
                'show_admin_column' => false,
                'hierarchical'      => true,
                'query_var'         => true,
                'rewrite'           => array(
                    'slug'          => 'category',
                    'with_front'    => false
                ) ,
            );

            register_taxonomy('portfolio_category', array(
                'milo_portfolio'
            ) , $category_args);

             // Register a taxonomy for Project Tags.
            $tag_labels = array(
                'name'              => esc_html__( 'Portfolio Tags', 'taxonomy general name', 'milo-bibo' ),
                'singular_name'     => esc_html__( 'Tag', 'taxonomy singular name', 'milo-bibo' ),
                'menu_name'         => esc_html__( 'Tags', 'milo-bibo' ) ,
                'search_items'      => esc_html__( 'Search Types', 'milo-bibo' ),
                'all_items'         => esc_html__( 'All Tags', 'milo-bibo' ),
                'parent_item'       => esc_html__( 'Parent Tag', 'milo-bibo' ),
                'parent_item_colon' => esc_html__( 'Parent Tag:', 'milo-bibo' ),
                'edit_item'         => esc_html__( 'Edit Tags', 'milo-bibo' ),
                'update_item'       => esc_html__( 'Update Tag', 'milo-bibo' ),
                'add_new_item'      => esc_html__( 'Add New Portfolio Tag', 'milo-bibo' ),
                'new_item_name'     => esc_html__( 'New Tag Name', 'milo-bibo' ),
            );

            $tag_args = array(
                'labels'       => $tag_labels,
                'public'       => true,
                'hierarchical' => false,
                'show_ui'      => true,
                'query_var'    => true,
                'rewrite'      => array( 
                    'slug'       => 'tag',
                    'with_front' => false
                ),
            );

            // Custom taxonomy for Project Tags
            register_taxonomy('portfolio_tag', array(
                'milo_portfolio'
            ), $tag_args);
        }

        // Add columns to Team Members
        function add_columns($columns) {
            unset(
                $columns['cb'],
                $columns['post-format'],
                $columns['title'],
                $columns['date']
            );
            $cols = array_merge(array('cb' => ('')), $columns);
            $cols = array_merge($cols, array('title' => esc_html__( 'Title', 'milo-bibo' )));
            $cols = array_merge($cols, array('category' => esc_html__( 'Category', 'milo-bibo' )));
            $cols = array_merge($cols, array('media_type' => esc_html__( 'Media Type', 'milo-bibo' )));
            $cols = array_merge($cols, array('thumbnail' => esc_html__( 'Thumbnail', 'milo-bibo' )));
            $cols = array_merge($cols, array('date' => esc_html__( 'Date', 'milo-bibo' )));

            return $cols;
        }

        // Set values for columns
        function set_columns_value($column, $post_id) {
            $prefix = $this->prefix;

            switch ($column) {
                case 'id': {
                    echo wp_kses_post($post_id);
                    break;
                }
                case 'media_type': {
                    $media_type = get_post_meta($post_id, "{$prefix}_media_type", true);
                    switch( $media_type ) {
                        case 'image':
                            echo '<label for="post-format-image" class="post-format-icon post-format-image"></label>';
                            break; 
                        case 'video':
                            echo '<label for="post-format-video" class="post-format-icon post-format-video"></label>';
                            break;
                        case 'link':
                            echo '<label for="post-format-link" class="post-format-icon post-format-link"></label>';
                            break;
                        case 'gallery':
                            echo '<label for="post-format-gallery" class="post-format-icon post-format-gallery"></label>';
                            break;
                        default:

                            break;
                    }
                    break;
                }
                case 'thumbnail': {
                    echo get_the_post_thumbnail($post_id, 'thumbnail');
                    break;
                }
                case 'category': {
                    $terms = get_the_terms( $post_id, 'portfolio_category' ); 
                    foreach($terms as $term) {
                        echo $term->name;
                    }
                    break;
                }

            }
        }

        // Register metaboxies
        function milo_register_meta_boxes() {
            $prefix = $this->prefix;

            $meta_boxes   = array();
            $meta_boxes[] = array(
                'id'          => "{$prefix}_meta_box_media_type",
                'title'       => esc_html__( 'Media Type', 'milo-bibo' ),
                'context'     => 'side',
                'post_types'  => array('milo_portfolio'),
                'priority'    => 'high',
                'description' => esc_html__( 'Choose the media type for this Portfolio Item.', 'milo-bibo' ),
                'fields'      => array(
                    array(
                        'id'    => "{$prefix}_media_type",
                        'type'  => 'radio',
                        'std'   => 'image',
                        'class' => 'milo-portfolio-post-type',
                        'options' => array(
                            'image'   => esc_html__( 'Image', 'milo-bibo' ),
                            'link'    => esc_html__( 'Link', 'milo-bibo' ),
                            'gallery' => esc_html__( 'Gallery', 'milo-bibo' ),
                            'video'   => esc_html__( 'Video', 'milo-bibo' ),
                        ),
                    ),
                    array(
                        'name'    => esc_html__( 'Thumbnail size', 'milo-bibo' ),
                        'id'      => "{$prefix}_thumbnail_size",
                        'type'    => 'select',
                        'class'   => 'milo-portfolio-thumbnail-size',
                        'options' => array(
                            ''              => esc_html__( 'Default', 'milo-bibo' ),
                            'small_squared' => esc_html__( 'Small Squared', 'milo-bibo' ),
                            'big_squared'   => esc_html__( 'Big Squared', 'milo-bibo' ),
                            'landscape'     => esc_html__( 'Landscape', 'milo-bibo' ),
                            'portrait'      => esc_html__( 'Portrait', 'milo-bibo' ),
                        ),
                        'multiple' => false,
                        'std'      => '',
                    ),
                    array(
                        'name'    => esc_html__( 'View Detail Style', 'milo-bibo' ),
                        'id'      => 'portfolio_detail_style',
                        'type'    => 'select',
                        'class'   => 'milo-portfolio-view-detail',
                        'options' => array(
                            'none'      => esc_html__( 'Inherit from theme options','milo-bibo' ),
                            'detail-01' => esc_html__( 'Fullwidth slide', 'milo-bibo' ),
                            'detail-02' => esc_html__( 'Vertical images', 'milo-bibo' ),
                            'detail-03' => esc_html__( 'Small slide', 'milo-bibo' ),
                            'detail-04' => esc_html__( 'Grid images 2 Columns', 'milo-bibo' ),
                            'detail-05' => esc_html__( 'Grid images 1 Columns', 'milo-bibo' )
                        ),
                        'multiple'    => false,
                        'std'         => 'none',
                    )
                ),
            );

            // PORTFOLIO FORMAT: Gallery
            //--------------------------------------------------
            $meta_boxes[] = array(
                'title'      => esc_html__( 'Post Format: Gallery', 'milo-bibo' ),
                'id'         => $prefix . 'meta_box_post_format_gallery',
                'post_types' => array('milo_portfolio'),
                'fields'     => array(
                    array(
                        'name' => esc_html__( 'Images', 'milo-bibo' ),
                        'id'   => $prefix . '_data_format_gallery',
                        'type' => 'image_advanced',
                        'desc' => esc_html__( 'Select images gallery for post','milo-bibo' )
                    ),
                ),
            );

            // PORTFOLIO FORMAT: Video
            //--------------------------------------------------
            $meta_boxes[] = array(
                'title'      => esc_html__( 'Post Format: Video', 'milo-bibo' ),
                'id'         => $prefix . 'meta_box_post_format_video',
                'post_types' => array('milo_portfolio'),
                'fields'     => array(
                    array(
                        'name' => esc_html__( 'Video URL or Embeded Code', 'milo-bibo' ),
                        'id'   => $prefix . '_data_format_video',
                        'type' => 'textarea',
                    ),
                ),
            );


            // POST FORMAT: LINK
            //--------------------------------------------------
            $meta_boxes[] = array(
                'title'      => esc_html__( 'Post Format: Link', 'milo-bibo' ),
                'id'         => $prefix . 'meta_box_post_format_link',
                'post_types' => array('milo_portfolio'),
                'fields'     => array(
                    array(
                        'name' => esc_html__( 'Url', 'milo-bibo' ),
                        'id'   => $prefix . '_data_format_link_url',
                        'type' => 'url',
                    ),
                    array(
                        'name' => esc_html__( 'Text', 'milo-bibo' ),
                        'id'   => $prefix . '_data_format_link_text',
                        'type' => 'text',
                    ),
                ),
            );

            // Use RW Metaboxies fields
            if ( class_exists('RW_Meta_Box') ) {
                foreach ($meta_boxes as $meta_box) {
                    new RW_Meta_Box($meta_box);
                }
            }
        }
    }

    new Milo_Portfolio_Post_Type;
}