<?php
/**
 * @package    MiloTheme/Milo Bibo
 * @version    1.0.0
 * @author     Administrator <admin@milotheme.com>
 * @copyright  Copyright (c) 2016, MiloTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       http://milotheme.com
*/

if ( ! class_exists( 'Milo_Teammember_Post_Type' ) ) {
    class Milo_Teammember_Post_Type {

        protected $prefix;

        public function __construct() {
            $this->prefix = 'milo_teammember';

            add_action('init', array($this,'milo_teammember'));
            add_action('admin_init', array($this, 'milo_register_meta_boxes'));

            if ( is_admin() ) {
                add_action( 'do_meta_boxes', array( $this, 'remove_plugin_metaboxes' ) );
                // Add custom columns reference: http://code.tumilolus.com/articles/add-a-custom-column-in-posts-and-custom-post-types-admin-screen--wp-24934
                add_filter( 'manage_milo_teammember_posts_columns', array( $this, 'add_columns' ) );
                add_action( 'manage_milo_teammember_posts_custom_column', array( $this, 'set_columns_value'), 10, 2);
            }
        }

        function remove_plugin_metaboxes() {
            remove_meta_box( 'mymetabox_revslider_0', 'milo_teammember', 'normal' );
            remove_meta_box( 'handlediv', 'milo_teammember', 'normal' );
            remove_meta_box( 'commentsdiv', 'milo_teammember', 'normal' );
        }

        function milo_teammember() {
            $prefix = $this->prefix;

            $labels = array(
                'menu_name'          => esc_html__( 'Team members', 'milo-bibo' ),
                'singular_name'      => esc_html__( 'Team member', 'milo-bibo' ),
                'name'               => esc_html__( 'Team members', 'milo-bibo' ),
                'add_new'            => esc_html__( 'Add New', 'milo-bibo' ) ,
                'add_new_item'       => esc_html__( 'Add New Team Member', 'milo-bibo' ) ,
                'edit_item'          => esc_html__( 'Edit Team Member', 'milo-bibo' ) ,
                'new_item'           => esc_html__( 'Add New Team Member', 'milo-bibo' ) ,
                'view_item'          => esc_html__( 'View Team Member', 'milo-bibo' ) ,
                'search_items'       => esc_html__( 'Search Team Member', 'milo-bibo' ) ,
                'not_found'          => esc_html__( 'No Team Member items found', 'milo-bibo' ) ,
                'not_found_in_trash' => esc_html__( 'No Team Member items found in trash', 'milo-bibo' ) ,
                'parent_item_colon'  => ''
            );

            $args = array(
                'labels'                => $labels,
                'description'           => esc_html__( 'Display members of team work', 'milo-bibo' ),
                'hierarchical'          => false,
                'public'                => false,
                'show_ui'               => true,
                'show_in_menu'          => true,
                'menu_icon'             => 'dashicons-groups',
                'menu_position'         => 5,
                'show_in_admin_bar'     => true,
                'show_in_nav_menus'     => true,
                'can_export'            => true,
                'has_archive'           => true,
                'exclude_from_search'   => false,
                'publicly_queryable'    => false,
                'capability_type'       => 'post',
                'supports'              => array( 'title', 'thumbnail'),
                'rewrite'           => array(
                    'slug'          => 'teammember',
                    'with_front'    => false
                ) ,
            );
            register_post_type( 'milo_teammember', $args );

            // Register a taxonomy for Project Categories.
            $category_labels = array(
                'name'                          => esc_html__( 'Team Categories', 'milo-bibo' ) ,
                'singular_name'                 => esc_html__( 'Team Category', 'milo-bibo' ) ,
                'menu_name'                     => esc_html__( 'Team Categories', 'milo-bibo' ) ,
                'all_items'                     => esc_html__( 'All Team Categories', 'milo-bibo' ) ,
                'edit_item'                     => esc_html__( 'Edit Team Category', 'milo-bibo' ) ,
                'view_item'                     => esc_html__( 'View Team Category', 'milo-bibo' ) ,
                'update_item'                   => esc_html__( 'Update Team Category', 'milo-bibo' ) ,
                'add_new_item'                  => esc_html__( 'Add New Team Category', 'milo-bibo' ) ,
                'new_item_name'                 => esc_html__( 'New Team Category Name', 'milo-bibo' ) ,
                'parent_item'                   => esc_html__( 'Parent Team Category', 'milo-bibo' ) ,
                'parent_item_colon'             => esc_html__( 'Parent Team Category:', 'milo-bibo' ) ,
                'search_items'                  => esc_html__( 'Search Team Categories', 'milo-bibo' ) ,
                'popular_items'                 => esc_html__( 'Popular Team Categories', 'milo-bibo' ) ,
                'separate_items_with_commas'    => esc_html__( 'Separate Team Categories with commas', 'milo-bibo' ) ,
                'add_or_remove_items'           => esc_html__( 'Add or remove Team Categories', 'milo-bibo') ,
                'choose_from_most_used'         => esc_html__( 'Choose from the most used Team Categories', 'milo-bibo' ) ,
                'not_found'                     => esc_html__( 'No Team Categories found', 'milo-bibo' ) ,
            );

            $category_args = array(
                'labels'            => $category_labels,
                'public'            => false,
                'show_ui'           => true,
                'show_in_nav_menus' => false,
                'show_tagcloud'     => false,
                'show_admin_column' => false,
                'hierarchical'      => true,
                'query_var'         => true,
                'rewrite'           => array(
                    'slug'          => 'category',
                    'with_front'    => false
                ) ,
            );

            register_taxonomy('team_category', array(
                'milo_teammember'
            ) , $category_args);
        }

        // Add columns to Team Members
        function add_columns($columns) {
            unset(
                $columns['cb'],
                $columns['title'],
                $columns['date']
            );
            $cols = array_merge(array('cb' => ('')), $columns);
            $cols = array_merge($cols, array('title' => esc_html__( 'Name', 'milo-bibo' )));
            $cols = array_merge($cols, array('position' => esc_html__( 'Position', 'milo-bibo' )));
            $cols = array_merge($cols, array('thumbnail' => esc_html__( 'Picture', 'milo-bibo' )));
            $cols = array_merge($cols, array('date' => esc_html__( 'Date', 'milo-bibo' )));

            return $cols;
        }

        // Set values for columns
        function set_columns_value($column, $post_id) {
            $prefix = $this->prefix;

            switch ($column) {
                case 'id': {
                    echo wp_kses_post($post_id);
                    break;
                }
                case 'position': {
                    echo get_post_meta($post_id, "{$prefix}_position", true);
                    break;
                }
                case 'thumbnail': {
                    echo get_the_post_thumbnail($post_id, 'thumbnail');
                    break;
                }
            }
        }

        // Register metaboxies
        function milo_register_meta_boxes() {
            $prefix = $this->prefix;

            $meta_boxes   = array();
            $meta_boxes[] = array(
                'id'            => "{$prefix}_meta_boxes",
                'title'         => esc_html__( 'Team Member Information:', 'milo-bibo' ),
                'post_types'    => array( 'milo_teammember' ),
                'fields'        => array(
                    array(
                        'id'    => "{$prefix}_name",
                        'name'  => esc_html__( 'Name', 'milo-bibo' ),
                        'type'  => 'text',
                    ),
                    array(
                        'id'    => "{$prefix}_position",
                        'name'  => esc_html__( 'Position', 'milo-bibo' ),
                        'type'  => 'text',
                    ),
                    // array(
                    //     'id'    => "{$prefix}_phone",
                    //     'name'  => esc_html__( 'Phone', 'milo-bibo' ),
                    //     'type'  => 'text',
                    // ),
                    // array(
                    //     'id'    => "{$prefix}_email",
                    //     'name'  => esc_html__( 'Email', 'milo-bibo' ),
                    //     'type'  => 'text',
                    // ),
                    // array(
                    //     'id'    => "{$prefix}_url",
                    //     'name'  => esc_html__( 'URL', 'milo-bibo' ),
                    //     'type'  => 'text',
                    // ),
                    // array(
                    //     'id'    => "{$prefix}_experience",
                    //     'name'  => esc_html__( 'Experience', 'milo-bibo' ),
                    //     'type'  => 'text',
                    // ),

                )
            );

            // @TODO: can add custom field in rw metabox to add social
            $meta_boxes[] = array(
                'id'            => "{$prefix}_meta_box_team_social",
                'title'         => esc_html__( 'Social Profiles', 'milo-bibo' ),
                'post_types'    => array( 'milo_teammember' ),
                'fields'        => array(
                    array(
                        'id'    => "{$prefix}_facebook",
                        'name'  => esc_html__( 'Facebook', 'milo-bibo' ),
                        'type'  => 'text',
                    ),
                    array(
                        'id'    => "{$prefix}_twitter",
                        'name'  => esc_html__( 'Twitter', 'milo-bibo' ),
                        'type'  => 'text',
                    ),
                    // array(
                    //     'id'    => "{$prefix}_google",
                    //     'name'  => esc_html__( 'Google +', 'milo-bibo' ),
                    //     'type'  => 'text',
                    // ),
                    array(
                        'id'    => "{$prefix}_instagram",
                        'name'  => esc_html__( 'Instagram', 'milo-bibo' ),
                        'type'  => 'text',
                    ),
                    // array(
                    //     'id'    => "{$prefix}_linkedin",
                    //     'name'  => esc_html__( 'Linkedin', 'milo-bibo' ),
                    //     'type'  => 'text',
                    // ),
                    // array(
                    //     'id'    => "{$prefix}_flickr",
                    //     'name'  => esc_html__( 'Flickr', 'milo-bibo' ),
                    //     'type'  => 'text',
                    // ),
                    // array(
                    //     'id'    => "{$prefix}_pinterest",
                    //     'name'  => esc_html__( 'Pinterest', 'milo-bibo' ),
                    //     'type'  => 'text',
                    // ),
                    
                    // array(
                    //     'id'    => "{$prefix}_tumblr",
                    //     'name'  => esc_html__( 'Tumblr', 'milo-bibo' ),
                    //     'type'  => 'text',
                    // )
                )
            );
            // $meta_boxes[] = array(
            //     'id'            => "{$prefix}_meta_box_specialty",
            //     'title'         => esc_html__( 'Specialty', 'milo-bibo' ),
            //     'post_types'    => array( 'milo_teammember' ),
            //     'fields'        => array(
            //         array(
            //             'id'        => "{$prefix}_sp_description",
            //             'name'      => esc_html__( 'Description', 'milo-bibo' ),
            //             'type'      => 'textarea',
            //         ),
            //     )
            // );
            // $meta_boxes[] = array(
            //     'id'            => "{$prefix}_meta_box_certificates",
            //     'title'         => esc_html__( 'Certificates', 'milo-bibo' ),
            //     'post_types'    => array( 'milo_teammember' ),
            //     'fields'        => array(
            //         array(
            //             'id'    => "{$prefix}_certificates_description",
            //             'name'  => esc_html__( 'Description', 'milo-bibo' ),
            //             'type'  => 'textarea',
            //         )
            //     )
            // );

            // Use RW Metaboxies fields
            if ( class_exists('RW_Meta_Box') ) {
                foreach ($meta_boxes as $meta_box) {
                    new RW_Meta_Box($meta_box);
                }
            }
        }
    }

    new Milo_Teammember_Post_Type;
}