<?php
/**
 * @package    MiloTheme/Milo Bibo
 * @version    1.0.0
 * @author     Administrator <admin@milotheme.com>
 * @copyright  Copyright (c) 2016, MiloTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       http://milotheme.com
*/

if ( !class_exists( 'Milo_Testimonial_Post_Type' ) ) {
    class Milo_Testimonial_Post_Type {

        protected $prefix;

        public function __construct() {
            $this->prefix = 'milo_testimonial';

            add_action('init', array($this,'milo_testimonial'));
            add_action('admin_init', array($this, 'milo_register_meta_boxes'));

            if( is_admin() ) {
                add_action( 'do_meta_boxes', array( $this, 'remove_plugin_metaboxes' ) );
                // Add custom columns reference: http://code.tumilolus.com/articles/add-a-custom-column-in-posts-and-custom-post-types-admin-screen--wp-24934
                add_filter( 'manage_milo_testimonial_posts_columns', array( $this, 'add_columns' ) );
                add_action( 'manage_milo_testimonial_posts_custom_column', array( $this, 'set_columns_value'), 10, 2);
            }
        }

        function remove_plugin_metaboxes() {
            remove_meta_box( 'mymetabox_revslider_0', 'milo_testimonial', 'normal' );
            remove_meta_box( 'handlediv', 'milo_testimonial', 'normal' );
            remove_meta_box( 'commentsdiv', 'milo_testimonial', 'normal' );
        }

        function milo_testimonial() {
            $labels = array(
                'name'               => esc_html__( 'Testimonials', 'milo-bibo' ),
                'singular_name'      => esc_html__( 'Testimonial', 'milo-bibo' ),
                'menu_name'          => esc_html__( 'Testimonials', 'milo-bibo' ),
                'add_new'            => esc_html__( 'Add New', 'milo-bibo' ) ,
                'add_new_item'       => esc_html__( 'Add New Testimonial', 'milo-bibo' ) ,
                'edit_item'          => esc_html__( 'Edit Testimonial', 'milo-bibo' ) ,
                'new_item'           => esc_html__( 'Add New Testimonial', 'milo-bibo' ) ,
                'view_item'          => esc_html__( 'View Testimonial', 'milo-bibo' ) ,
                'search_items'       => esc_html__( 'Search Testimonial', 'milo-bibo' ) ,
                'not_found'          => esc_html__( 'No Testimonial items found', 'milo-bibo' ) ,
                'not_found_in_trash' => esc_html__( 'No Testimonial items found in trash', 'milo-bibo' ) ,
                'parent_item_colon'  => '',
                'rewrite'           => array(
                    'slug'          => 'testimonial',
                    'with_front'    => false
                ) ,
            );

            $args = array(
                'labels'                => $labels,
                'description'           => esc_html__( 'Display client\'s testimonials', 'milo-bibo' ),
                'supports'              => array( 'title', 'editor', 'thumbnail' ),
                'hierarchical'          => false,
                'public'                => true,
                'show_ui'               => true,
                'show_in_menu'          => true,
                'menu_icon'             => 'dashicons-id',
                'menu_position'         => 5,
                'show_in_admin_bar'     => true,
                'show_in_nav_menus'     => true,
                'can_export'            => true,
                'has_archive'           => true,
                'exclude_from_search'   => false,
                'publicly_queryable'    => true,
                'capability_type'       => 'post',
            );

            register_post_type( 'milo_testimonial', $args );

            // Register a taxonomy for Testimonials Categories.
            $category_labels = array(
                'name'                          => esc_html__( 'Testimonial Categories', 'milo-bibo' ) ,
                'singular_name'                 => esc_html__( 'Testimonial Category', 'milo-bibo') ,
                'menu_name'                     => esc_html__( 'Testimonial Categories', 'milo-bibo' ) ,
                'all_items'                     => esc_html__( 'All Testimonial Categories', 'milo-bibo' ) ,
                'edit_item'                     => esc_html__( 'Edit Testimonial Category', 'milo-bibo' ) ,
                'view_item'                     => esc_html__( 'View Testimonial Category', 'milo-bibo' ) ,
                'update_item'                   => esc_html__( 'Update Testimonial Category', 'milo-bibo' ) ,
                'add_new_item'                  => esc_html__( 'Add New Testimonial Category', 'milo-bibo' ) ,
                'new_item_name'                 => esc_html__( 'New Testimonial Category Name', 'milo-bibo' ) ,
                'parent_item'                   => esc_html__( 'Parent Testimonial Category', 'milo-bibo' ) ,
                'parent_item_colon'             => esc_html__( 'Parent Testimonial Category:', 'milo-bibo' ) ,
                'search_items'                  => esc_html__( 'Search Testimonial Categories', 'milo-bibo' ) ,
                'popular_items'                 => esc_html__( 'Popular Testimonial Categories', 'milo-bibo') ,
                'separate_items_with_commas'    => esc_html__( 'Separate Testimonial Categories with commas', 'milo-bibo' ) ,
                'add_or_remove_items'           => esc_html__( 'Add or remove Testimonial Categories', 'milo-bibo' ) ,
                'choose_from_most_used'         => esc_html__( 'Choose from the most used Testimonial Categories', 'milo-bibo' ) ,
                'not_found'                     => esc_html__( 'No Testimonial Categories found', 'milo-bibo' ) ,
            );

            $category_args = array(
                'labels'            => $category_labels,
                'public'            => false,
                'show_ui'           => true,
                'show_in_nav_menus' => false,
                'show_tagcloud'     => false,
                'show_admin_column' => false,
                'hierarchical'      => true,
                'query_var'         => true,
                'rewrite'           => array(
                    'slug'          => 'category',
                    'with_front'    => false
                ) ,
            );

            register_taxonomy('testimonial_category', array(
                'milo_testimonial'
            ) , $category_args);
        }

        // Add columns to Testimonial
        function add_columns($columns) {
            unset(
                $columns['cb'],
                $columns['title'],
                $columns['date']
            );
            $cols = array_merge(array('cb' => ('')), $columns);
            $cols = array_merge($cols, array('title' => esc_html__( 'Name', 'milo-bibo' )));
            $cols = array_merge($cols, array('email' => esc_html__( 'Email', 'milo-bibo' )));
            $cols = array_merge($cols, array('thumbnail' => esc_html__( 'Picture', 'milo-bibo' )));
            $cols = array_merge($cols, array('date' => esc_html__( 'Date', 'milo-bibo' )));

            return $cols;
        }

        // Set values for columns
        function set_columns_value($column, $post_id) {
            $prefix = $this->prefix;
            
            switch ($column) {
                case 'id': {
                    echo wp_kses_post($post_id);
                    break;
                }
                case 'email': {
                    echo get_post_meta($post_id, "{$prefix}_email", true);
                    break;
                }
                case 'thumbnail': {
                    echo get_the_post_thumbnail($post_id, 'thumbnail');
                    break;
                }
            }
        }

        // Register metaboxies
        function milo_register_meta_boxes() {
            $prefix       = $this->prefix;

            $meta_boxes   = array();
            $meta_boxes[] = array(
                'id'            => "{$prefix}_meta_boxes",
                'title'         => esc_html__( 'Testimonial Information:', 'milo-bibo' ),
                'post_types'    => array( 'milo_testimonial' ),
                'fields'        => array(
                    array(
                        'id'    => "{$prefix}_email",
                        'name'  => esc_html__( 'Email', 'milo-bibo' ),
                        'type'  => 'text',
                    ),
                    array(
                        'id'    => "{$prefix}_position",
                        'name'  => esc_html__( 'Position', 'milo-bibo' ),
                        'type'  => 'text',
                    ),
                    array(
                        'id'    => "{$prefix}_url",
                        'name'  => esc_html__( 'URL', 'milo-bibo' ),
                        'type'  => 'text',
                    ),
                    array(
                        'id'    => "{$prefix}_special",
                        'name'  => esc_html__( 'Special', 'milo-bibo' ),
                        'type'  => 'text',
                    ),
                    array(
                        'id'      => "{$prefix}_rating",
                        'name'  => esc_html__( 'Rating', 'milo-bibo' ),
                        'type'    => 'select',
                        'options' => array(
                            '-1'  => esc_html__( 'no rating', 'milo-bibo' ),
                            '0'   => esc_html__( '0 star', 'milo-bibo' ),
                            '0.5' => esc_html__( '0.5 star', 'milo-bibo' ),
                            '1'   => esc_html__( '1 star', 'milo-bibo' ),
                            '1.5' => esc_html__( '1.5 stars', 'milo-bibo' ),
                            '2'   => esc_html__( '2 stars', 'milo-bibo' ),
                            '2.5' => esc_html__( '2.5 stars', 'milo-bibo' ),
                            '3'   => esc_html__( '3 stars', 'milo-bibo' ),
                            '3.5' => esc_html__( '3.5 stars', 'milo-bibo' ),
                            '4'   => esc_html__( '4 stars', 'milo-bibo' ),
                            '4.5' => esc_html__( '4.5 stars', 'milo-bibo' ),
                            '5'   => esc_html__( '5 stars', 'milo-bibo' ),
                        )
                    ),
                    array(
                        'id'    => "{$prefix}_background",
                        'name'  => esc_html__( 'Background Image', 'milo-bibo' ),
                        'type'  => 'image_advanced',
                    ),
                )
            );
            
            // Use RW Metaboxies fields
            if ( class_exists('RW_Meta_Box') ) {
                foreach ($meta_boxes as $meta_box) {
                    new RW_Meta_Box($meta_box);
                }
            }
        }
    }

    new Milo_Testimonial_Post_Type;
}