<?php
/**
 * @package    MiloTheme/Milo Bibo
 * @version    1.0.0
 * @author     Administrator <admin@milotheme.com>
 * @copyright  Copyright (c) 2016, MiloTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       http://milotheme.com
*/

if ( ! defined( 'ABSPATH' ) ) die( '-1' );

if ( ! class_exists('Milo_Framework_Shortcode_Blog') ) {
    class Milo_Framework_Shortcode_Blog {
        function __construct() {
            add_shortcode( 'milo_blog', array( $this, 'milo_blog_shortcode' ) );
        }

        function milo_blog_shortcode($atts) {
            $atts = vc_map_get_attributes( 'milo_blog', $atts );
            $type = $columns = $category = $max_items = $paging_style = $posts_per_page = $paging_align = $orderby = $order = $meta_key = $el_class = $milo_animation = $css_animation = $duration = $delay = $styles_animation = '';
            extract(shortcode_atts(array(
                'type'           => 'large-image',
                'columns'        => '2',
                'padding'        => '',
                'category'       => '',
                'max_items'      => '',
                'paging_style'   => 'all',
                'posts_per_page' => '',
                'paging_align'   => 'right',
                'orderby'        => 'date',
                'order'          => 'DESC',
                'meta_key'       => '',
                'excerpt_length' => '20',
                'el_class'       => '',
                'css_animation'  => '',
                'duration'       => '',
                'delay'          => ''
            ), $atts));
            if (is_front_page()) {
                $paged   = get_query_var( 'page' ) ? intval( get_query_var( 'page' ) ) : 1;
            } else {
                $paged   = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
            }

            $args = array(
                'post_type'           => 'post',
                'paged'               => $paged,
                'ignore_sticky_posts' => true,
                'posts_per_page'      => $max_items > 0 ? $max_items : $posts_per_page,
                'orderby'             => $orderby,
                'order'               => $order,
                'meta_key'            => $orderby == 'meta_key' ? $meta_key : '',
            );

            if ( $paging_style == 'all' && $max_items == -1 ) {
                $args['nopaging'] = true;
            }

            if ( !empty($category) ) {
                $args['tax_query'] = array(
                    array(
                        'taxonomy' 		=> 'category',
                        'terms' 		=>  explode(',', $category),
                        'field' 		=> 'slug',
                        'operator' 		=> 'IN'
                    )
                );
            }
            // var_dump($args);

            query_posts($args);

            $milo_animation   .= ' ' . esc_attr($el_class);
            $milo_animation   .= MILO_BiboCore_Shortcodes::milo_get_css_animation($css_animation);
            $styles_animation = MILO_BiboCore_Shortcodes::milo_get_style_animation($duration, $delay);

            $blog_wrapper_class   = array('archive-content');
            $blog_wrapper_class[] = $type;
            
            $blog_class        = array('archive-content-layout','clearfix');
            $blog_class[]      = 'layout-style-' . $type;

            $blog_paging_class   = array('blog-paging-wrapper');
            $blog_paging_class[] = 'blog-paging-'.$paging_style;


            $archive_content_class   = array('blog-inner');
            $archive_content_class[] = 'blog-style-' . $type;
            $archive_content_class[] = 'blog-paging-' . $paging_style;

            // global $milo_archive_loop;
            // switch ($type) {
            //     case 'large-image':
            //         $milo_archive_loop['image-size'] = 'blog-large-image-full-width';
            //         break;
            //     case 'medium-image':
            //         $milo_archive_loop['image-size'] = 'blog-medium-image';
            //         break;
            //     case 'grid':
            //         $milo_archive_loop['image-size'] = 'blog-grid';
            //         break;
            // }

            // $milo_archive_loop['style'] = $type;
            ob_start();
            ?>
            <div class="<?php echo esc_attr($milo_animation . ' ' . $styles_animation); ?>">
                <div class="blog-shortcode-wrapper">
                    <div class="<?php echo join(' ',$blog_wrapper_class); ?>">
                        <div class="<?php echo join(' ',$blog_class); ?>">
                            <div class="row">
                                <div class="<?php echo join(' ',$archive_content_class); ?>">
                                    <?php
                                    if ( have_posts() ) :
                                        // Start the Loop.
                                        while ( have_posts() ) : the_post();
                                            /*
                                             * Include the post format-specific template for the content. If you want to
                                             * use this in a child theme, then include a file called called content-___.php
                                             * (where ___ is the post format) and that will be used instead.
                                             */
                                            get_template_part( 'templates/archive/content' , get_post_format() );
                                        endwhile;
                                        //milo_archive_loop_reset();
                                    else :
                                        // If no content, include the "No posts found" template.
                                        get_template_part( 'templates/archive/content-none');
                                    endif;
                                    ?>
                                </div>
                            </div>
                        </div>

                        <?php
                        global $wp_query;
                        if ( $wp_query->max_num_pages > 1 && $max_items == -1 ) :
                            ?>
                            <div class="archive-paging <?php echo esc_attr($paging_style); ?>">
                                <?php
                                switch($paging_style) {
                                    case 'load-more':
                                        milo_paging_load_more();
                                        break;
                                    case 'infinity-scroll':
                                        milo_paging_infinitescroll();
                                        break;
                                    default:
                                        echo milo_paging_nav();
                                        break;
                                }
                                ?>
                            </div>
                        <?php endif;?>

                    </div>
                </div>
            </div>
            <?php
            wp_reset_query();
            $content =  ob_get_clean();

            return $content;
        }
    }

    new Milo_Framework_Shortcode_Blog();
}