<?php
/**
 * @package    MiloTheme/Milo Bibo
 * @version    1.0.0
 * @author     Administrator <admin@milotheme.com>
 * @copyright  Copyright (c) 2016, MiloTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       http://milotheme.com
 *
 * 1. Set templates shortcode
 * 2. Add shortcode param
 * 2.1. Add shortcode param datetimepicker
*/

/*
* 1. Set templates shortcode
*/
function milo_sc_locate_template( $template_name, $template_path = '', $default_path ='' ) {

    if ( ! $template_path ) :
        $template_path = 'milo-bibo/shortcodes/';
    endif;

    if ( ! $default_path ) :
        // $default_path = MILO_BIBO_SC_OUTPUT_DIR;
    endif;

    // Search template file in theme folder.
    $template = locate_template( array(
        $template_path . $template_name,
        $template_name
    ) );

    // Get plugins template file.
    if ( ! $template ) :
        $template = $default_path . $template_name;
    endif;

    return apply_filters( 'milo_sc_locate_template', $template, $template_name, $template_path, $default_path );
}

function milo_sc_get_template( $template_name, $args = array(), $template_path = '', $default_path = '' ) {
    if ( is_array( $args ) && isset( $args ) ) :
        extract( $args );
    endif;
    $template_file = milo_sc_locate_template( $template_name, $template_path, $default_path );
    if ( ! file_exists( $template_file ) ) :
        _doing_it_wrong( __FUNCTION__, sprintf( '<code>%s</code> does not exist.', $template_file ), '1.0.0' );
        return;
    endif;
    include $template_file;
}

/* 2. Add shortcode param 
* More details here: https://wpbakery.atlassian.net/wiki/display/VC/Create+New+Param+Type
*/
/* 2.1. Add shortcode param datetime picker */
if ( ! function_exists( 'milo_shortcode_param_datetime' ) ) :
    function milo_shortcode_param_datetime( $settings, $value ) {
        // Load datetimepicker library from admin
        $html[] = '<div class="milo_datetime_param">';
        $html[] = '     <input name="' . esc_attr( $settings['param_name'] ) . '" class="wpb_vc_param_value wpb-textinput ' . esc_attr( $settings['param_name'] ) . ' ' . esc_attr( $settings['type'] ) . '_field" type="text" value="' . esc_attr( $value ) . '" id="datetimepicker"/>';
        $html[] = '</div>';

        return implode( "\n", $html );
    }

    vc_add_shortcode_param( 'milo_datetime', 'milo_shortcode_param_datetime', plugins_url() . '/milo-bibo-core/admin/assets/js/admin.js' );
endif;

if ( ! function_exists( 'milo_number_settings_field' ) ) :
    function milo_number_settings_field( $settings, $value ) {
        $param_name = isset($settings['param_name']) ? $settings['param_name'] : '';
        $type       = isset($settings['type']) ? $settings['type'] : '';
        $min        = isset($settings['min']) ? $settings['min'] : '';
        $max        = isset($settings['max']) ? $settings['max'] : '';
        $suffix     = isset($settings['suffix']) ? $settings['suffix'] : '';
        $class      = isset($settings['class']) ? $settings['class'] : '';
        $output     = '<input type="number" min="' . esc_attr($min) . '" max="' . esc_attr($max) . '" class="wpb_vc_param_value ' . esc_attr($param_name) . ' ' . esc_attr($type) . ' ' . esc_attr($class) . '" name="' . esc_attr($param_name) . '" value="' . esc_attr($value) . '" style="max-width:100px; margin-right: 10px;" />' . esc_attr($suffix);
        
        return $output;
    }

    vc_add_shortcode_param('number', 'milo_number_settings_field');
endif;  

if ( ! function_exists( 'milo_icon_text_settings_field' ) ) :
    function milo_icon_text_settings_field( $settings, $value ) {
        return '<div class="vc-text-icon">'
        . '<input  name="' . $settings['param_name'] . '" style="width:80%;" class="wpb_vc_param_value wpb-textinput widefat input-icon ' . esc_attr($settings['param_name']) . ' ' . esc_attr($settings['type']) . '_field" type="text" value="' . esc_attr($value) . '"/>'
        . '<input title="' . esc_html__('Click to browse icon', 'milo-bibo') . '" style="width:20%; height:34px;" class="browse-icon button-secondary" type="button" value="' . esc_html__('Browse Icon', 'milo-bibo') . '" >'
        . '<span class="icon-preview"><i class="' . esc_attr($value) . '"></i></span>'
        . '</div>';
    }

    vc_add_shortcode_param('icon_text', 'milo_icon_text_settings_field');
endif; 

if ( ! function_exists( 'milo_multi_select_settings_field_shortcode_param' ) ) :
    function milo_multi_select_settings_field_shortcode_param( $settings, $value ) {
        $param_name = isset($settings['param_name']) ? $settings['param_name'] : '';
        $param_option = isset($settings['options']) ? $settings['options'] : '';
        $output = '<input type="hidden" name="' . $param_name . '" id="' . $param_name . '" class="wpb_vc_param_value ' . $param_name . '" value="' . $value . '"/>';
        $output .= '<select multiple id="' . $param_name . '_select2" name="' . $param_name . '_select2" class="multi-select">';
        if ($param_option != '' && is_array($param_option)) {
            foreach ($param_option as $text_val => $val) {
                if (is_numeric($text_val) && (is_string($val) || is_numeric($val))) {
                    $text_val = $val;
                }
                $output .= '<option id="' . $val . '" value="' . $val . '">' . htmlspecialchars($text_val) . '</option>';
            }
        }

        $output .= '</select><input type="checkbox" id="' . $param_name . '_select_all" >' . esc_html__( 'Select All', 'milo-bibo' );
        $output .= '<script type="text/javascript">
                    jQuery(document).ready(function($){

                        $("#' . $param_name . '_select2").select2();

                        var order = $("#' . $param_name . '").val();
                        if (order != "") {
                            order = order.split(",");
                            var choices = [];
                            for (var i = 0; i < order.length; i++) {
                                var option = $("#' . $param_name . '_select2 option[value="+ order[i]  + "]");
                                if (option.length > 0) {
                                    choices[i] = {id:order[i], text:option[0].label, element: option};
                                }
                            }
                            $("#' . $param_name . '_select2").select2("data", choices);
                        }

                        $("#' . $param_name . '_select2").on("select2-selecting", function(e) {
                            var ids = $("#' . $param_name . '").val();
                            if (ids != "") {
                                ids +=",";
                            }
                            ids += e.val;
                            $("#' . $param_name . '").val(ids);
                        }).on("select2-removed", function(e) {
                              var ids = $("#' . $param_name . '").val();
                              var arr_ids = ids.split(",");
                              var newIds = "";
                              for(var i = 0 ; i < arr_ids.length; i++) {
                                if (arr_ids[i] != e.val){
                                    if (newIds != "") {
                                        newIds +=",";
                                    }
                                    newIds += arr_ids[i];
                                }
                              }
                              $("#' . $param_name . '").val(newIds);
                         });

                        $("#' . $param_name . '_select_all").click(function(){
                            if($("#' . $param_name . '_select_all").is(":checked") ){
                                $("#' . $param_name . '_select2 > option").prop("selected","selected");
                                $("#' . $param_name . '_select2").trigger("change");
                                var arr_ids =  $("#' . $param_name . '_select2").select2("val");
                                var ids = "";
                                for (var i = 0; i < arr_ids.length; i++ ) {
                                    if (ids != "") {
                                        ids +=",";
                                    }
                                    ids += arr_ids[i];
                                }
                                $("#' . $param_name . '").val(ids);

                            }else{
                                $("#' . $param_name . '_select2 > option").removeAttr("selected");
                                $("#' . $param_name . '_select2").trigger("change");
                                $("#' . $param_name . '").val("");
                            }
                        });
                    });
                    </script>
                    <style>
                        .multi-select {
                          width: 100%;
                        }
                        .select2-drop {
                            z-index: 100000;
                        }
                    </style>';
        return $output;
    }

    vc_add_shortcode_param('multi-select', 'milo_multi_select_settings_field_shortcode_param');
endif;

if ( ! function_exists( 'milo_single_select_settings_field_shortcode_param' ) ) :
    function milo_single_select_settings_field_shortcode_param( $settings, $value ) {
        $param_name = isset($settings['param_name']) ? $settings['param_name'] : '';
        $param_option = isset($settings['options']) ? $settings['options'] : '';
        $output = '<input type="hidden" name="' . $param_name . '" id="' . $param_name . '" class="wpb_vc_param_value ' . $param_name . '" value="' . $value . '"/>';
        $output .= '<select id="' . $param_name . '_select2" name="' . $param_name . '_select2" class="single-select">';
        if ($param_option != '' && is_array($param_option)) {
            $output .= '<option value="">'. esc_html_e('Select a product', 'milo-bibo') .'</option>';
            foreach ($param_option as $text_val => $val) {
                if (is_numeric($text_val) && (is_string($val) || is_numeric($val))) {
                    $text_val = $val;
                }
                if( $val == $value ) {
                    $selected = 'selected';
                } else {
                    $selected = '';
                }
                $output .= '<option id="' . $val . '" value="' . $val . '"'. $selected .'>' . htmlspecialchars($text_val) . '</option>';
            }
        }

        $output .= '</select>';
        $output .= '<script type="text/javascript">
                    jQuery(document).ready(function($){
                        $("#' . $param_name . '_select2").select2({
                            placeholder: "Select a product"
                        });
                        $( "select[name=\'' . $param_name . '_select2\']" ).click( function() {
                            var selected_value = $(this).find("option:selected").val();
                            $( "input[name=\'' . $param_name . '\']" ).val( selected_value );
                        });
                    });
                    </script>
                    <style>
                        .multi-select {
                          width: 100%;
                        }
                        .select2-drop {
                            z-index: 100000;
                        }
                    </style>';
        return $output;
    }

    vc_add_shortcode_param('single-select', 'milo_single_select_settings_field_shortcode_param');
endif;

if ( ! function_exists( 'milo_tags_settings_field_shortcode_param' ) ) :
    function milo_tags_settings_field_shortcode_param( $settings, $value ) {
        $param_name = isset($settings['param_name']) ? $settings['param_name'] : '';
        $output     =   '<input  name="' . $settings['param_name']
                        . '" class="wpb_vc_param_value wpb-textinput '
                        . $settings['param_name'] . ' ' . $settings['type']
                        . '" type="hidden" value="' . $value . '"/>';
        $output     .= '<input type="text" name="' . $param_name . '_tagsinput" id="' . $param_name . '_tagsinput" value="' . $value . '" data-role="tagsinput"/>';
        $output     .= '<script type="text/javascript">
                            jQuery(document).ready(function($){
                                $("input[data-role=tagsinput], select[multiple][data-role=tagsinput]").tagsinput();

                                $("#' . $param_name . '_tagsinput").on("itemAdded", function(event) {
                                     $("input[name=' . $param_name . ']").val($(this).val());
                                });

                                $("#' . $param_name . '_tagsinput").on("itemRemoved", function(event) {
                                     $("input[name=' . $param_name . ']").val($(this).val());
                                });
                            });
                        </script>';
        return $output;
    }

    vc_add_shortcode_param('tags', 'milo_tags_settings_field_shortcode_param');
endif;