<?php
/**
 * @package    MiloTheme/Milo Bibo
 * @version    1.0.0
 * @author     Administrator <admin@milotheme.com>
 * @copyright  Copyright (c) 2016, MiloTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       http://milotheme.com
*/

if( empty($product_cats) ) {
    $sub_cats = get_terms('product_cat', array('parent' => $parent_cat, 'fields' => 'ids', 'orderby' => 'none'));
    if( is_array($sub_cats) && !empty($sub_cats) ) {
        $product_cats = implode(',', $sub_cats);
    } else {
        return;
    }
    $see_more_link = get_term_link((int)$parent_cat, 'product_cat');
    if( is_wp_error($see_more_link) ) {
        $see_more_link = '#';
    }
} else {
    $see_more_link = get_permalink( wc_get_page_id('shop') );
}

?>
<div class="<?php echo esc_attr(implode(' ', $classes)); ?>" id="<?php echo esc_attr($rand_id) ?>" data-atts="<?php echo htmlentities(json_encode($atts)); ?>">

    <ul class="products-tabs clearfix">
        <?php if ( $show_general_tab == 1 ) : ?>
            <li class="tab-item all-tab" data-product_cat="<?php echo esc_attr($product_cats) ?>" data-link="<?php echo esc_url($see_more_link) ?>"><?php echo esc_html( 'All', 'milo-bibo' ); ?></li>
        <?php endif; ?>

        <?php
            if ( !empty($product_cats) ) : 
                $category_arr = array_filter(explode(',', $product_cats));
                foreach( $category_arr as $cat ) : 
                    $category = get_term_by('slug', $cat, 'product_cat');
        ?>
            <li class="tab-item" data-product_cat="<?php echo esc_attr($category->slug); ?>" data-link="<?php echo esc_url(get_term_link( (int) $category->term_id, 'product_cat')) ?>">
                <span><?php echo esc_html($category->name); ?></span>
            </li>
        <?php
                endforeach;
            endif; 
        ?>
    </ul>
    
    <div class="products-content <?php echo $layout_type; ?>">
    </div>

    <!-- See more button (not loadmore) -->
    <div class="see-more-wrapper">
        <a class="button see-more-button" href="<?php echo esc_url($see_more_link) ?>"><?php echo esc_html__( 'See More', 'milo-bibo' ); ?></a>
    </div>

</div>
<script>
    !function($) {
        $(document).ready(function() {
            var products_in_category_tabs_data = [];
            
            /* Change tab */
            $('.products-in-category-tabs-wrapper.grid .products-tabs .tab-item').bind('click', function() {
                if ( $(this).hasClass('current') || $(this).parents('.products-in-category-tabs-wrapper').find('.products-content').hasClass('loading') ){
                    return;
                }
                var element       = $(this).parents('.products-in-category-tabs-wrapper');
                var element_id    = element.attr('id');
                var product_cat   = $(this).data('product_cat');
                var see_more_link = $(this).data('link');
                var atts          = element.data('atts');
                
                var is_all_tab = $(this).hasClass('all-tab') ? 1 : 0;
                
                if ( element.find('a.see-more-button').length > 0 ) {
                    element.find('a.see-more-button').attr('href', see_more_link);
                }
                
                element.find('.products-tabs .tab-item').removeClass('current');
                $(this).addClass('current');
                
                /* Check cache */
                var tab_data_index = element_id + '-' + product_cat.toString().split(',').join('-');
                if ( products_in_category_tabs_data[tab_data_index] != undefined ){
                    element.find('.products-content .products').remove();
                    element.find('.products-content').append( products_in_category_tabs_data[tab_data_index] );

                    /* See more button handle */
                    milo_product_in_category_tab_see_more_handle( element, atts );
                    
                    return;
                }
                
                element.find('.products-content').addClass('loading');
                
                $.ajax({
                    type : "POST",
                    timeout : 30000,
                    url : milo_framework_ajax_url,
                    data : {
                        action: 'milo_get_product_content_in_category_tab', 
                        atts: atts, 
                        product_cat: product_cat, 
                        is_all_tab: is_all_tab
                    },
                    error: function(xhr,err) {
                        
                    },
                    success: function(response) {
                        if( response ) {       
                            element.find('.products-content .products').remove();
                            element.find('.products-content').append( response ).find('li.product-type').css('opacity',0).animate({opacity: 1},500);

                            /* save cache */
                            products_in_category_tabs_data[tab_data_index] = response;
                            
                            /* See more button handle */
                            milo_product_in_category_tab_see_more_handle( element, atts );

                            /* Generate isotope */
                            milo_product_in_category_tab_isotope( element );
                        }
                        element.find('.products-content').removeClass('loading');

                        MILO.woocommerce.init();
                        MILO.common.init();
                    }
                });
            });
            
            $('.products-in-category-tabs-wrapper.grid').each(function() {
                $(this).find('.products-tabs .tab-item:first').trigger('click');
            });

            // Isotope product grid
            function milo_product_in_category_tab_isotope(element) {
                if( element.find('.products-content.grid li.type-product').length > 0 ) {
                    setTimeout(function(){
                        element.find('.products-content.grid .products').isotope({
                            itemSelector : 'li.type-product',
                            layoutMode: 'fitRows'
                        });
                    }, 100);
                }
            }

            // See more product
            function milo_product_in_category_tab_see_more_handle(element, atts) {
                var hide_see_more = element.find('.products .hide-see-more').length;
                element.find('.products .hide-see-more').remove();
                
                if( element.find('.tab-item.current').hasClass('general-tab') && atts.hide_see_more_general_tab == 1 ){
                    hide_see_more = true;
                }
                
                if( element.find('.products .product').length == 0 ) {
                    hide_see_more = true;
                }
                
                if( atts.show_see_more_button == 1 ) {
                    if( hide_see_more ){
                        element.find('.see-more-wrapper').addClass('hidden');
                        element.removeClass('has-see-more-button');
                    }
                    else{
                        element.find('.see-more-wrapper').removeClass('hidden');
                        element.addClass('has-see-more-button');
                    }
                }
            }
            
        });
    } (jQuery);
</script>