<?php
/**
 * @package    MiloTheme
 * @version    1.0.0
 * @author     Administrator <admin@milotheme.com>
 * @copyright  Copyright (c) 2016, MiloTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       http://milotheme.com
*/
if ( ! defined( 'ABSPATH' ) ) die( '-1' );

if ( ! class_exists('Milo_Framework_Shortcode_Products_List') ) {
    class Milo_Framework_Shortcode_Products_List {
        function __construct() {
            add_shortcode( 'milo_products_list', array( $this, 'milo_products_list_shortcode' ) );
        }

        function milo_products_front_scripts() {
            
        }

        function milo_products_list_shortcode($atts) {
            $this->milo_products_front_scripts();
            global $woocommerce;      

            $atts        = vc_map_get_attributes( 'milo_products_list', $atts );
            $data_source = $category = $product_ids = $paging_style = $per_page = $paging_align = $orderby = $order = $el_class = $css_animation = $duration = $delay = $milo_animation = $styles_animation = '';
            extract(shortcode_atts(array(
                'data_source'        => '',
                'category'           => '',
                'product_ids'        => '',
                'per_page'           => '4',
                'paging_style'       => 'default', // page number
                'paging_align'       => 'center',
                'orderby'            => 'date',
                'order'              => 'asc',
                'el_class'           => '',
                'css_animation'      => '',
                'duration'           => '',
                'delay'              => ''
            ), $atts));

            if (is_front_page()) {
                $paged   = get_query_var( 'page' ) ? intval( get_query_var( 'page' ) ) : 1;
            } else {
                $paged   = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
            }
            $milo_animation = '';
            $milo_animation   .= ' ' . esc_attr($el_class);
            $milo_animation   .= MILO_BiboCore_Shortcodes::milo_get_css_animation($css_animation);
            $styles_animation = MILO_BiboCore_Shortcodes::milo_get_style_animation($duration, $delay);

            $product_paging_class            = array('products-shortcode-paging-wrapper');
            $product_paging_class[]          = 'paging-'.$paging_style;
            $product_paging_class[]          = 'text-' . $paging_align;
            
            // Get products
            $ordering_args = $woocommerce->query->get_catalog_ordering_args($orderby, $order);
            $meta_query    = $woocommerce->query->get_meta_query();

            $args = array(
                'post_type'           => 'product',
                'post_status'         => 'publish',
                'ignore_sticky_posts' => 1,
                'orderby'             => $ordering_args['orderby'],
                'order'               => $ordering_args['order'],
                'posts_per_page'      => $per_page,
                'meta_query'          => $meta_query,
                'paged'               => $paged
            );

            if ( ! empty($category) ) {
                $args['tax_query'] = array(
                    array(
                        'taxonomy' => 'product_cat',
                        'terms'    => array_map('sanitize_title', explode(',', $category)),
                        'field'    => 'slug',
                        'operator' => 'IN'
                    )
                );
            }

            if (isset($ordering_args['meta_key'])) {
                $args['meta_key'] = $ordering_args['meta_key'];
            }

            // If data_source = product_IDs
            if ( $data_source == 'product_list_id' ) {
                 $args = array(
                    'post_type'      => 'product',
                    'post_status'    => 'publish',
                    'orderby'        => $orderby,
                    'order'          => $order,
                    'posts_per_page' => $per_page,
                    'post__in'       => explode( ',' , $product_ids ),
                );
            }

            ob_start();

            $products = new WP_Query($args);

            $plugin_path   = untrailingslashit(plugin_dir_path(__FILE__));
            $template_path = $plugin_path . '/templates/layout/list.php';
            $product_path  = $plugin_path . '/templates/product-style/list_style.php'; // Use this to override content-product of woocommerce

            ?>

            <?php if ( $products->have_posts() ) : ?>
                <div class="<?php echo esc_attr($milo_animation . ' ' . $styles_animation); ?>">
                    <?php include($template_path); ?>
                </div>
            <?php else : ?>
                <div class="item-not-found"><?php echo esc_html__( 'No item found', 'milo-bibo' ) ?></div>
            <?php endif; ?>

            <?php
            wp_reset_query();
            
            $content =  ob_get_clean();
            
            return $content;
        }
    }

    new Milo_Framework_Shortcode_Products_List();
}