<?php
/**
 * @package    MiloTheme
 * @version    1.0.0
 * @author     Administrator <admin@milotheme.com>
 * @copyright  Copyright (c) 2016, MiloTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       http://milotheme.com
*/
if ( ! defined( 'ABSPATH' ) ) die( '-1' );

if ( ! class_exists('Milo_Framework_Shortcode_Products_Slider') ) {
    class Milo_Framework_Shortcode_Products_Slider {
        function __construct() {
            add_shortcode( 'milo_products_slider', array($this, 'milo_products_slider_shortcode' ) );
        }

        function milo_products_front_scripts() {
            wp_enqueue_style( 'milo-owl-carousel', get_template_directory_uri() . '/assets/libraries/owl-carousel/assets/owl.carousel.min.css', array(),false );
            wp_enqueue_script( 'milo-owl-carousel', get_template_directory_uri() . '/assets/libraries/owl-carousel/owl.carousel.min.js', false, true );
        }

        function milo_products_slider_shortcode($atts) {
            global $woocommerce;
            $this->milo_products_front_scripts(); 

            $atts  = vc_map_get_attributes( 'milo_products_slider', $atts );
            $layout_type = $data_source = $category = $product_ids = $products_per_slide = $autoplay = $slide_duration = $per_page = $orderby = $order = $el_class = $css_animation = $duration = $delay = $milo_animation = $styles_animation = '';
            extract(shortcode_atts(array(
                'layout_type'        => 'carousel',
                'data_source'        => '',
                'category'           => '',
                'product_ids'        => '',
                'products_per_slide' => '2',
                'autoplay'           => 'true',
                'slide_duration'     => '3000',
                'per_page'           => '-1',
                'orderby'            => 'date',
                'order'              => 'asc',
                'el_class'           => '',
                'css_animation'      => '',
                'duration'           => '',
                'delay'              => ''
            ), $atts));

            if (is_front_page()) {
                $paged   = get_query_var( 'page' ) ? intval( get_query_var( 'page' ) ) : 1;
            } else {
                $paged   = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
            }
            $milo_animation    = '';
            $milo_animation   .= ' ' . esc_attr($el_class);
            $milo_animation   .= MILO_BiboCore_Shortcodes::milo_get_css_animation($css_animation);
            $styles_animation = MILO_BiboCore_Shortcodes::milo_get_style_animation($duration, $delay);
            
            // Get products
            $ordering_args = $woocommerce->query->get_catalog_ordering_args($orderby, $order);
            $meta_query    = $woocommerce->query->get_meta_query();

            $args = array(
                'post_type'           => 'product',
                'post_status'         => 'publish',
                'ignore_sticky_posts' => 1,
                'orderby'             => $ordering_args['orderby'],
                'order'               => $ordering_args['order'],
                'posts_per_page'      => $per_page,
                'meta_query'          => $meta_query,
                'paged'               => $paged
            );

            if ( ! empty($category) ) {
                $args['tax_query'] = array(
                    array(
                        'taxonomy' => 'product_cat',
                        'terms'    => array_map('sanitize_title', explode(',', $category)),
                        'field'    => 'slug',
                        'operator' => 'IN'
                    )
                );
            }

            if (isset($ordering_args['meta_key'])) {
                $args['meta_key'] = $ordering_args['meta_key'];
            }

            // If data_source = product_IDs
            if ( $data_source == 'product_list_id' ) {
                 $args = array(
                    'post_type'      => 'product',
                    'post_status'    => 'publish',
                    'orderby'        => $orderby,
                    'order'          => $order,
                    'posts_per_page' => $per_page,
                    'post__in'       => explode( ',' , $product_ids ),
                );
            }

            ob_start();

            $products = new WP_Query($args);

            $plugin_path = untrailingslashit(plugin_dir_path(__FILE__));

            $template_path = $plugin_path . '/templates/layout/slider.php';
            
            ?>

            <?php if ( $products->have_posts() ) : ?>
                <div class="<?php echo esc_attr($milo_animation . ' ' . $styles_animation); ?>">
                    <?php include($template_path); ?>
                </div>
            <?php else : ?>
                <div class="item-not-found"><?php echo esc_html__( 'No item found', 'milo-bibo' ) ?></div>
            <?php endif; ?>

            <?php
            wp_reset_query();
            
            $content =  ob_get_clean();
            
            return $content;
        }
    }

    new Milo_Framework_Shortcode_Products_Slider();
}