<?php
/**
 * Plugin Name: Milo Bibo Core
 * Plugin URI: http://milotheme.com
 * Description: The Milo Bibo Core plugin.
 * Version: 2.0.0
 * Author: MiloTheme
 * Author URI: http://milotheme.com
 *
 * Text Domain: milo-bibo
 * Domain Path: /languages/
 *
 * @package Milo Bibo Core
 * @category Core Plugin
 * @author MiloTheme
 *
 **/

if (!defined('ABSPATH')) {
    exit; // Exit if access directly
}

if ( ! class_exists( 'MILO_BiboCore' ) ) {
    class MILO_BiboCore {
        protected $loader;

        protected $prefix;

        protected $version;

        function __construct() {
            $this->version = '2.0.0';
            $this->prefix = 'milo-bibo-core';
            $this->define_constants();
            $this->include_files();
            $this->define_hook();
        }

        function define_constants() {
            if( !defined( 'PLUGIN_MILO_BIBO_CORE_DIR' ) ) {
                define( 'PLUGIN_MILO_BIBO_CORE_DIR', plugin_dir_path(__FILE__) );
            }
            if( !defined( 'PLUGIN_MILO_BIBO_CORE_URL' ) ) {
                define( 'PLUGIN_MILO_BIBO_CORE_URL', plugin_dir_url( __FILE__ ) );
            }
            if( !defined( 'PLUGIN_MILO_BIBO_CORE_FILE' ) ) {
                define( 'PLUGIN_MILO_BIBO_CORE_FILE', __FILE__ );
            }
            if( !defined( 'PLUGIN_MILO_BIBO_CORE_NAME' ) ) {
                define( 'PLUGIN_MILO_BIBO_CORE_NAME', 'milo-bibo-core' );
            }
            if( !defined( 'MILO_BIBO_CORE_SHORTCODE_CATEGORY' ) ) {
                define( 'MILO_BIBO_CORE_SHORTCODE_CATEGORY', esc_html__( 'Bibo Shortcodes', 'milo-bibo-core' ) );
            }
        }

        function include_files() {
            require_once( 'includes/milo_core_loader.php' );
            $this->loader = new MILO_BiboCore_Loader();

            if ( !class_exists('WPAlchemy_MetaBox') ) {
                include_once( 'includes/libraries/wpalchemy/MetaBox.php' );
            }

            require_once( 'admin/milo_core_admin.php' );
            require_once( 'includes/maintenance/_init.php' );
            require_once( 'includes/posttypes/_init.php' );
            require_once( 'includes/shortcodes/shortcodes.php' );
            require_once( 'includes/widgets/widgets.php' );
            require_once( 'includes/term-meta/index.php' ); // Add term meta to product attributes
        }

        public function load_plugin_textdomain() {
            load_plugin_textdomain( 'milo-bibo', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/'  );
        }

        private function define_hook() {

            // Apply filter do_shortcode
            add_filter('widget_text', 'do_shortcode');
            add_filter('widget_content', 'do_shortcode');

            /* set locale */
            $this->loader->add_action( 'plugins_loaded', $this, 'load_plugin_textdomain' );

            /* admin */
            $plugin_admin = new MILO_BiboCore_Admin( $this->get_prefix(), $this->get_version() );

            $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
            $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');
        }

        public function get_version() {
            return $this->version;
        }

        public function get_prefix() {
            return $this->prefix;
        }

        public function run() {
            $this->loader->run();
        }

    }

    // Run MILO_BiboCore
    if( !function_exists( 'init_milo_bibo_core' ) ) {
        function init_milo_bibo_core() {
            $miloBiboFramework = new MILO_BiboCore();
            $miloBiboFramework->run();
        }
    }

    init_milo_bibo_core();
}
